<?php
/*
 * Contains a list of all custom action hooks and corresponding functions defined for Suffusion. 
 * This file is included in functions.php
 */

// First we will get all options from the database, then we will individually invoke the options within each function as required.
global $options;
foreach ($options as $value) {
    if (get_option($value['id']) === FALSE) {
    	$$value['id'] = $value['std'];
    }
    else {
    	$$value['id'] = get_option( $value['id'] );
    }
}

//
// The following section defines different hooks with actions
//

add_action('suffusion_document_header', 'suffusion_include_skin');
add_action('suffusion_document_header', 'suffusion_include_dbx');
add_action('suffusion_document_header', 'suffusion_include_ie_fixes');
add_action('suffusion_document_header', 'suffusion_include_custom_styles');
add_action('suffusion_document_header', 'suffusion_include_custom_header_js');

add_action('suffusion_page_header', 'suffusion_display_header');
add_action('suffusion_page_header', 'suffusion_display_navigation');

add_action('suffusion_page_navigation', 'suffusion_display_hierarchical_navigation');

add_action('suffusion_after_begin_container', 'suffusion_print_widget_area_below_header');
add_action('suffusion_after_begin_container', 'suffusion_print_left_sidebars');

add_action('suffusion_content', 'suffusion_excerpt_or_content');

add_action('suffusion_before_end_container', 'suffusion_print_right_sidebars');
add_action('suffusion_before_end_container', 'suffusion_print_widget_area_above_footer');

add_action('suffusion_page_footer', 'suffusion_display_footer');

add_action('suffusion_document_footer', 'suffusion_include_custom_footer_js');

/*
 * The following section says what to do for each action
 */
function suffusion_document_header() {
	do_action('suffusion_document_header');
}

function suffusion_page_header() {
	do_action('suffusion_page_header');
}

function suffusion_after_begin_container() {
	do_action('suffusion_after_begin_container');
}

function suffusion_content() {
	do_action('suffusion_content');
}

function suffusion_before_end_container() {
	do_action('suffusion_before_end_container');
}

function suffusion_page_footer() {
	do_action('suffusion_page_footer');
}

function suffusion_document_footer() {
	do_action('suffusion_document_footer');
}

function suffusion_page_navigation() {
	do_action('suffusion_page_navigation');
}

//
// This section defines the individual callback functions
//

/*
 * Determines the theme selected by the user and includes the stylesheet for it
 */
function suffusion_include_skin() {
	global $suf_color_scheme;
	$skin = "dark-green.css";
	if (substr($suf_color_scheme, 0, 10) == "dark-theme") {
		$skin = "dark-".substr($suf_color_scheme, 11).".css";
	}
	else {
		$skin = substr($suf_color_scheme, 12).".css";
	}
?>
	<link rel="stylesheet" href="<?php bloginfo('stylesheet_directory'); ?>/<?php echo $skin;?>" type="text/css" media="all"/>
	<link rel="stylesheet" href="<?php bloginfo('stylesheet_directory'); ?>/print.css" type="text/css" media="print" />
<?php
}

function suffusion_include_dbx() {
	global $suf_sidebar_1_dnd, $suf_sidebar_2_dnd, $suf_sidebar_1_expcoll, $suf_sidebar_2_expcoll, $suf_sidebar_count;
	if ($suf_sidebar_count == 0 ||
		($suf_sidebar_count == 1 && $suf_sidebar_1_dnd != "enabled") || 
		($suf_sidebar_1_dnd != "enabled" && $suf_sidebar_2_dnd != "enabled")) {
		// No point in including the rather large dbx.js if Drag-and-drop is disabled for both sidebars, or if the sidebars themselves are disabled.
	}
	else {
		$expcoll_1 = $suf_sidebar_1_expcoll == "enabled" ? "yes" : "no";
		$expcoll_2 = $suf_sidebar_2_expcoll == "enabled" ? "yes" : "no";
?>
	<!-- Sidebar docking boxes (dbx) by Brothercake - http://www.brothercake.com/ -->
	<script type="text/javascript" src="<?php bloginfo('stylesheet_directory'); ?>/dbx.js"></script>
	<script type="text/javascript">
	/* <![CDATA[ */
	window.onload = function() {
		//initialise the docking boxes manager
		var manager = new dbxManager('main'); 	//session ID [/-_a-zA-Z0-9/]
		
<?php
		if ($suf_sidebar_1_dnd == "enabled") {?>
		//create new docking boxes group
		var sidebar = new dbxGroup(
			'sidebar', 		// container ID [/-_a-zA-Z0-9/]
			'vertical', 		// orientation ['vertical'|'horizontal']
			'7', 			// drag threshold ['n' pixels]
			'no',			// restrict drag movement to container axis ['yes'|'no']
			'10', 			// animate re-ordering [frames per transition, or '0' for no effect]
			'<?php echo $expcoll_1; ?>', 			// include open/close toggle buttons ['yes'|'no']
			'open', 		// default state ['open'|'closed']
			'open', 		// word for "open", as in "open this box"
			'close', 		// word for "close", as in "close this box"
			'click-down and drag to move this box', // sentence for "move this box" by mouse
			'click to %toggle% this box', // pattern-match sentence for "(open|close) this box" by mouse
			'use the arrow keys to move this box', // sentence for "move this box" by keyboard
			', or press the enter key to %toggle% it',  // pattern-match sentence-fragment for "(open|close) this box" by keyboard
			'%mytitle%  [%dbxtitle%]' // pattern-match syntax for title-attribute conflicts
		);
<?php
		}
		if ($suf_sidebar_count > 1) {
			if ($suf_sidebar_2_dnd == "enabled") {
?>
		var sidebar_2 = new dbxGroup(
			'sidebar-2', 		// container ID [/-_a-zA-Z0-9/]
			'vertical', 		// orientation ['vertical'|'horizontal']
			'7', 			// drag threshold ['n' pixels]
			'no',			// restrict drag movement to container axis ['yes'|'no']
			'10', 			// animate re-ordering [frames per transition, or '0' for no effect]
			'<?php echo $expcoll_2; ?>', 			// include open/close toggle buttons ['yes'|'no']
			'open', 		// default state ['open'|'closed']
			'open', 		// word for "open", as in "open this box"
			'close', 		// word for "close", as in "close this box"
			'click-down and drag to move this box', // sentence for "move this box" by mouse
			'click to %toggle% this box', // pattern-match sentence for "(open|close) this box" by mouse
			'use the arrow keys to move this box', // sentence for "move this box" by keyboard
			', or press the enter key to %toggle% it',  // pattern-match sentence-fragment for "(open|close) this box" by keyboard
			'%mytitle%  [%dbxtitle%]' // pattern-match syntax for title-attribute conflicts
		);
<?php
			}
		}?>
	};
	/* ]]> */
	</script>

<?php
	}
	// We will include the css, nonetheless, because we require the styles from it ?>
	<link rel="stylesheet" type="text/css" href="<?php bloginfo('stylesheet_directory'); ?>/dbx.css" media="screen, projection" />

<?php
}

function suffusion_include_ie_fixes() {?>
<!--[if lt IE 8]>
<link rel="stylesheet" href="<?php bloginfo('stylesheet_directory'); ?>/ie-fix.css" type="text/css" media="all" />
<script src="http://ie7-js.googlecode.com/svn/version/2.0(beta3)/IE8.js" type="text/javascript"></script>
<![endif]-->

<!--[if lt IE 7]>
<script src="<?php bloginfo('stylesheet_directory'); ?>/belatedpng.js"></script>
<script>
	//Drew Diller's Belated PNG: http://dillerdesign.wordpress.com/2009/07/02/belatedpng-img-nodes-javascript-event-handling/
  	DD_belatedPNG.fix('.png_bg, img, .suf-widget ul li, #sidebar ul li, #sidebar-2 ul li, input, .searchform .searchsubmit, submit, .searchsubmit, .postdata .category, .postdata .comments, .postdata .edit, .previous-entries a, .next-entries a, .post-nav .next a, .post-nav .previous a, .post .date, h3#comments, #h3#respond');
 </script>
<![endif]-->

<?php
}

function suffusion_include_custom_styles() {
	global $suf_custom_css_link_1, $suf_custom_css_link_2, $suf_custom_css_link_3, $suf_custom_css_code;
?>
	<!-- CSS styles constructed using option definitions -->
	<style type="text/css">
<?php
	include_once (TEMPLATEPATH . '/custom-styles.php');
?>
	</style>
	<!-- /CSS styles constructed using option definitions -->

	<!-- Custom CSS stylesheets linked through options -->
<?php 
	if (isset($suf_custom_css_link_1) && trim($suf_custom_css_link_1) != "") { ?>
	<link rel="stylesheet" href="<?php echo $suf_custom_css_link_1; ?>" type="text/css" media="all" />
<?php
	}
	if (isset($suf_custom_css_link_2) && trim($suf_custom_css_link_2) != "") {?>
	<link rel="stylesheet" href="<?php echo $suf_custom_css_link_2; ?>" type="text/css" media="all" />
<?php
	}
	if (isset($suf_custom_css_link_3) && trim($suf_custom_css_link_3) != "") {?>
	<link rel="stylesheet" href="<?php echo $suf_custom_css_link_3; ?>" type="text/css" media="all" />
<?php }?>
	<!-- /Custom CSS stylesheets -->

<?php
if (isset($suf_custom_css_code) && trim($suf_custom_css_code) != "") { ?>
	<!-- Custom CSS styles defined in options -->
	<style type="text/css">
<?php echo $suf_custom_css_code; ?>
	</style>
	<!-- /Custom CSS styles defined in options -->
<?php }
}

function suffusion_include_custom_header_js() {
	global $suf_custom_header_js;
	if (isset($suf_custom_header_js) && trim($suf_custom_header_js) != "") {?>
<!-- Custom JavaScript for header defined in options -->
<script type="text/javascript">
/* <![CDATA[ */
<?php echo $suf_custom_header_js."\n"; ?>
/* ]]> */
</script>
<!-- /Custom JavaScript for header defined in options -->
<?php
	}
}

function suffusion_display_header() {
	global $suf_sub_header_vertical_alignment;?>
    <div id="header" class="fix">
	<?php
	if ($suf_sub_header_vertical_alignment == "above") {	?>
   		<div class="description"><?php echo bloginfo('description');?></div>
   		<h1 class="blogtitle"><a href="<?php echo get_option('home');?>"><?php echo bloginfo('name');?></a></h1>
	<?php
	}
	else {	?>
   		<h1 class="blogtitle"><a href="<?php echo get_option('home');?>"><?php echo bloginfo('name');?></a></h1>
   		<div class="description"><?php echo bloginfo('description');?></div>
<?php
	}	?>
    </div><!-- /header -->
<?php
}

function suffusion_display_navigation() {
	global $suf_nav_contents;
?>
 	<div id="nav" class="fix">
<?php
	//Two options using native WP functionality:
	//1. wp_list_pages('title_li=&sort_column=menu_order&depth=3'); // This will need you to add the starting and ending <ul> tags
	//2. wp_page_menu('show_home=Home&menu_class=nav'); // This needs nothing and even creates the div. Works only for WP 2.7+
	//I am using a custom function here because I want to show the ">" for items with a dropdown. Also, page exclusions don't work as desired with standard functionality.
	if ($suf_nav_contents == "pages") {
		create_nav();
	}
	suffusion_display_right_header_widgets();
?>
	</div><!-- /nav -->
<?php
}

function suffusion_display_right_header_widgets() {
	global $suf_right_header_widgets_enabled, $suf_show_search;
	if ($suf_right_header_widgets_enabled == "enabled") {?>
		<!-- right-header-widgets -->
		<div id="right-header-widgets">
		<?php
			if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar('Right Header Widgets') ) {
				if ($suf_show_search == "show") {
					include (TEMPLATEPATH . '/searchform.php'); 
				}
			}
		?>
		</div>
		<!-- /right-header-widgets -->
<?php
	}
}

/*
 * Displays the widget area below the header, if it is enabled.
 */
function suffusion_print_widget_area_below_header() {
	global $suf_widget_area_below_header_enabled;
	if ($suf_widget_area_below_header_enabled == "enabled") {?>
	<!-- horizantal-outer-widgets-1 Widget Area -->
	<div id="horizontal-outer-widgets-1" class="dbx-group fix">
		<?php
			if (!function_exists('dynamic_sidebar') || !dynamic_sidebar('Widget Area Below Header')) {
			}
		?>
	</div>
	<!-- /horizantal-outer-widgets-1 --><?php
	}
}

/*
 * Prints the left sidebars, if the sidebars are enabled and are positioned on the left
 */
function suffusion_print_left_sidebars() {
	global $suf_sidebar_count, $suf_sidebar_alignment, $suf_sidebar_2_alignment;
	if (is_page_template("no-sidebars.php") || is_page_template("no-widgets.php")) {
		return;
	}
	if ($suf_sidebar_count > 0) {
		if ($suf_sidebar_alignment == "left") {
			get_sidebar();
		}
	}

	if ($suf_sidebar_count > 1) {
		if ($suf_sidebar_2_alignment == "left") {
			get_sidebar(2);
		}
	}
}

/*
 * Displays the right sidebars, if the sidebars are enabled and are positioned on the right
 */
function suffusion_print_right_sidebars() {
	global $suf_sidebar_count, $suf_sidebar_alignment, $suf_sidebar_2_alignment;
	if (is_page_template("no-sidebars.php") || is_page_template("no-widgets.php")) {
		return;
	}
	if ($suf_sidebar_count > 0) {
		if ($suf_sidebar_alignment == "right") {
			get_sidebar();
		}
	}
	if ($suf_sidebar_count > 1) {
		if ($suf_sidebar_2_alignment == "right") {
			get_sidebar(2);
		}
	}
}

/*
 * Displays the widget area above the footer, if it is enabled.
 */
function suffusion_print_widget_area_above_footer() {
	global $suf_widget_area_above_footer_enabled;
	if ($suf_widget_area_above_footer_enabled == "enabled") {
?>
	<!-- horizantal-outer-widgets-2 Widget Area -->
	<div id="horizontal-outer-widgets-2" class="fix">
		<?php
			if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar('Widget Area Above Footer') ) {
			}
		?>
	</div>
	<!-- /horizantal-outer-widgets-2 -->
<?php
	}
}

function suffusion_display_footer() {
?>
  <div id="cred">
	<div class="designer">&copy; 2009 <a href="http://www.aquoid.com/news/themes/suffusion/">Suffusion</a> <a href="http://wordpress.org/extend/themes/">WordPress theme</a> by <a href="http://mynethome.net/blog">Sayontan Sinha</a></div>
	<div class="valid"></div>
<!--	<div class="valid fix"><a href="http://validator.w3.org/check/referer">Valid XHTML</a></div>-->
  </div><!-- cred -->

<!-- <?php echo get_num_queries(); ?> queries in <?php timer_stop(1); ?> seconds. -->
<?php
}

function suffusion_include_custom_footer_js() {
	global $suf_custom_footer_js;
	if (isset($suf_custom_footer_js) && trim($suf_custom_footer_js) != "") {
?>
<!-- Custom JavaScript for footer defined in options -->
<script type="text/javascript">
/* <![CDATA[ */
	<?php echo $suf_custom_footer_js."\n"; ?>
/* ]]> */
</script>
<!-- /Custom JavaScript for footer defined in options -->
<?php }
}

function suffusion_get_siblings_in_nav($ancestors, $index, $exclusion_list, $exclude, $echo = 1) {
	if (count($ancestors) <= $index || $index < 0) {
		return;
	}
	$exclusion_query = $exclude == "hide" ? "&exclude=".$exclusion_list : "";
	$children = wp_list_pages("title_li=&child_of=".$ancestors[$index]."&echo=".$echo.$exclusion_query);
	return $children;
}

function suffusion_display_hierarchical_navigation() {
	global $post, $suf_nav_breadcrumb, $suf_nav_exclude_in_breadcrumb;
	$ancestors = $post->ancestors;
	$exclusion_list = get_excluded_pages("suf_nav_pages");
	$num_ancestors = count($ancestors);
	
	if ($suf_nav_breadcrumb == "all") {
		for ($anc_index = 1; $num_ancestors - $anc_index >= 0; $anc_index++) {
			$style = ($anc_index == 1) ? "subnav" : "l".($anc_index + 1)."nav";
?>
	<div id="<?php echo $style;?>" class="fix">
		<ul> 
			<?php suffusion_get_siblings_in_nav($ancestors, $num_ancestors - $anc_index, $exclusion_list, $suf_nav_exclude_in_breadcrumb); ?>
		</ul>
	</div><?php echo "<!-- /".$style."-->"; ?>
<?php
		}
		$exclusion_query = $suf_nav_exclude_in_breadcrumb == "hide" ? "&exclude_tree=".$exclusion_list : "";
		$style = ($num_ancestors == 0) ? "subnav" : "l".($num_ancestors + 2)."nav";
		$children = wp_list_pages("title_li=&child_of=".$post->ID."&echo=0".$exclusion_query);
		if ($children) {
	?>
	<div id="<?php echo $style;?>" class="fix">
		<ul>
			<?php echo $children; ?>
		</ul>
	</div><!-- /sub nav -->
<?php
		}
	}
	suffusion_create_navigation_breadcrumb();
}

function suffusion_create_navigation_breadcrumb() {
	global $suf_nav_breadcrumb, $suf_breadcrumb_separator, $post;
	
	$ancestors = $post->ancestors;
	$num_ancestors = count($ancestors);
	if ($suf_nav_breadcrumb == "breadcrumb") {
		$anc_limit = $num_ancestors > 1 ? $num_ancestors - 2 : ($num_ancestors > 0 ? $num_ancestors - 1 : 0);
		if ($num_ancestors > 0) {
	?>
	<div id="subnav" class="fix">
		<div class="breadcrumb">
	<?php
			for ($i = $num_ancestors-1; $i>=0; $i--) {
				$anc_page = get_page($ancestors[$i]);
				echo "<a href='".get_permalink($ancestors[$i])."'>".$anc_page->post_title."</a> ".$suf_breadcrumb_separator." ";
			}
			echo $post->post_title;
	?>
		</div>
	</div><!-- /sub nav -->
	<?php
		}
	}
}

function suffusion_excerpt_or_content() {
	global $suf_category_excerpt, $suf_tag_excerpt, $suf_archive_excerpt, $suf_index_excerpt;
	if ((is_category() && $suf_category_excerpt == "excerpt") ||
		(is_tag() && $suf_tag_excerpt == "excerpt") ||
		(is_archive() && !is_tag() && !is_category() && $suf_archive_excerpt == "excerpt") ||
		$suf_index_excerpt == "excerpt") {
		the_excerpt();
	}
	else {
		the_content(__('Continue reading', 'suf_theme').' &raquo;');
	}
}
?>
